---------------------
oslo-config-generator
---------------------

.. automodule:: oslo.config.generator

.. currentmodule:: oslo.config.generator

.. autofunction:: main
.. autofunction:: generate
.. autofunction:: register_cli_opts
